/*
** config.c -- master nmh configuration file
**
** This code is Copyright (c) 2002, by the authors of nmh.  See the
** COPYRIGHT file in the root directory of the nmh distribution for
** complete copyright information.
*/

#include <h/mh.h>



/*
** nmh globals
*/

char *mhlibdir = NMHLIBDIR;
char *mhetcdir = NMHETCDIR;

char *invo_name;        /* command invocation name    */
char *mypath;           /* user's $HOME               */
char *mmhpath;          /* pathname of user's mmh dir */
char *defpath;          /* pathname of user's profile */
char *ctxpath;          /* pathname of user's context */
char ctxflags;          /* status of user's context   */
struct node *m_defs;    /* profile/context structure  */


/*
** nmh constants: standard file names
**
** Important: Adjust uip/mmh.sh if you make changes here!
*/

/* default name of the mail storage */
char *mailstore = "Mail";

/* default name of user profile */
char *mmhdir = ".mmh";

/* default name of user profile */
char *profile = "profile";

/* default name for the nmh context file */
char *context = "context";

/*
** Default name of file for public sequences. Gets overridden
** by a `Mh-Sequences' entry in the user's profile. Set to NULL
** or the empty string to use private sequences by default.
*/
char *mh_seq = ".mh_sequences";

/* standard component files */
char *components     = "components";       /* comp         */
char *replcomps      = "replcomps";        /* repl         */
char *replgroupcomps = "replgroupcomps";   /* repl -group  */
char *forwcomps      = "forwcomps";        /* forw         */
char *distcomps      = "distcomps";        /* dist         */
char *rcvdistcomps   = "rcvdistcomps";     /* rcvdist      */
char *digestcomps    = "digestcomps";      /* forw -digest */

/* standard format (filter) files */
char *mhlformat      = "mhl.format";       /* show         */
char *mhlreply       = "mhl.reply";        /* repl -filter */
char *mhlforward     = "mhl.forward";      /* forw -filter */


/*
** standard names for: mail folders, sequences, and profile entries
*/

/* some default folder names */
char *defaultfolder = "+inbox";
char *draftfolder = "+drafts";

char *inbox = "Inbox";  /* profile entry name to specify the default folder */
char *curfolder = "Current-Folder";

/* predefined sequences */
char *seq_all    = "a";
char *seq_beyond = "b";  /* the previous `new' sequence */
char *seq_cur    = "c";
char *seq_first  = "f";
char *seq_last   = "l";
char *seq_next   = "n";
char *seq_prev   = "p";
char *seq_unseen = "u";
char *seq_neg    = "!";

char *usequence = "Unseen-Sequence";
char *psequence = "Previous-Sequence";
char *nsequence = "Sequence-Negation";

/* profile entries for storage locations */
char *nmhstorage   = "nmh-storage";
char *nmhcache     = "nmh-cache";
char *nmhprivcache = "nmh-private-cache";

/* profile entry for external ftp access command */
char *nmhaccessftp = "nmh-access-ftp";

/* Default attachment header field name */
char *attach_hdr = "Attach";

/* the tool to query the mime type of a file */
char *mimetypequery = "Mime-Type-Query";
char *mimetypequeryproc = "file -b --mime";



/*
** nmh default programs
*/

/*
** This is the program to process MIME composition files
*/
char *buildmimeproc = NMHBINDIR"/mhbuild";

/*
** This is the program to `cat' a file.
*/
char *catproc = "/bin/cat";

/*
** This program is usually called directly by users, but it is
** also invoked by the spost program to process an "Fcc", or by
** comp/repl/forw/dist to refile a draft message.
*/
char *fileproc = NMHBINDIR"/refile";

/*
** This program is called to incorporate messages into a folder.
*/
char *incproc = NMHBINDIR"/inc";

/*
** This is the default program invoked by a "list" response
** at the "What now?" prompt.  It is also used by the draft
** folder facility in comp/dist/forw/repl to display the
** draft message.
*/
char *lproc = "more";

/*
** This is the path for the Bell equivalent mail program.
*/
char *mailproc = NMHBINDIR"/mhmail";

/*
** This is used by mhl as a front-end.  It is also used
** by mhshow as the default method of displaying message bodies
** or message parts of type text/plain.
*/
char *moreproc = "more";

/*
** This is the editor invoked by the various message
** composition programs.  It SHOULD be a full screen
** editor, such as vi or emacs, but any editor will work.
*/
char *defaulteditor = "vi";

/*
** This is the delivery program called by send to actually
** deliver mail to users.  This is the interface to the MTS.
*/
char *postproc = NMHLIBDIR"/spost";

/*
** This is program is called by slocal to handle
** the action `folder' or `+'.
*/
char *rcvstoreproc = NMHLIBDIR"/rcvstore";

/*
** This program is called to remove a message by rmm or refile -nolink.
** It's usually empty, which means to rename the file to a backup name.
*/
char *rmmproc = NULL;

/*
** This program is usually called by the user's whatnowproc, but it
** may also be called directly to send a message previously composed.
 */
char *sendproc = NMHBINDIR"/send";

/*
** This is the path to the program used by "show"
** to display non-text (MIME) messages.
*/
char *showmimeproc = NMHBINDIR"/mhshow";

/*
** This is the default program called by "show" to filter
** and display standard text (non-MIME) messages.  It can be
** changed to a pager (such as "more" or "less") if you prefer
** that such message not be filtered in any way.
*/
char *showproc = NMHLIBDIR"/mhl";

/*
** This is the program (mhl) used to filter messages.  It is
** used by mhshow to filter and display the message headers of
** MIME messages.  It is used by repl/forw (with -filter)
** to filter the message to which you are replying/forwarding.
** It is used by send/spost (with -filter) to filter the message
** for "Bcc:" recipients.
*/
char *mhlproc = NMHLIBDIR"/mhl";

/*
** This program is called after comp, et. al., have built a draft
*/
char *whatnowproc = NMHBINDIR"/whatnow";

/*
** This is the sendmail interface to use for sending mail.
*/
char *sendmail = SENDMAILPATH;

/*
** This is the path to the system mail spool directory (e.g. `/var/mail').
*/
char *mailspool = MAILSPOOL;


/*
** file stuff
*/

/*
** The prefix that is prepended to the name of message files when they
** are "removed" by rmm. This should typically be `,' or `#'.
*/
char *backup_prefix = ",";

/*
** Name of link to file to which you are replying or which you are
** redistributing. See `$mhaltmsg' in the mh-profile(5) man page.
*/
char *altmsglink = "@";

/*
** Folders (directories) are created with this protection (mode)
*/
char *foldprot = "700";

/*
** Every NEW message will be created with this protection.  When a
** message is filed it retains its protection, so this only applies
** to messages coming in through inc.
*/
char *msgprot = "600";



/*
** Standard yes/no switches structure
*/
struct swit anoyes[] = {
	{ "no", 0 },
	{ "yes", 0 },
	{ NULL, 0 }
};

